@@ -108,8 +108,8 @@ prepare_param_in_pxe_cfg(){
        ;;
     clonezilla-live)
        if [ -z "$server_IP" ]; then
-         # Find the IP address of this server. Here we choose the first one in the list, since it's just an example.
-         server_IP="$(LC_ALL=C get-all-nic-ip -i | awk -F" " '{print $1}')"
+         # Find the IP address of this server. Here we choose the first one in the list of those connected to DRBL clients.
+         server_IP="$(LC_ALL=C get-all-nic-ip -b | awk -F" " '{print $1}')"
        fi
        get_rootfs_location_opt
        if [ -z "$cl_gp_boot_param" ]; then
